<!DOCTYPE html>
<html>
<head>
    <title>Редактор блога</title>
    <meta charset="utf-8">
    <style>
        body {
            font-family: Arial, sans-serif;
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
        }
        form {
            display: flex;
            flex-direction: column;
            gap: 15px;
        }
        textarea {
            min-height: 200px;
            padding: 10px;
            line-height: 1.6;
            font-size: 14px;
            font-family: Arial, sans-serif;
            white-space: pre-wrap;
            resize: vertical;
        }
        .formatting-buttons {
            display: flex;
            gap: 5px;
            margin-bottom: 10px;
        }
        .format-btn {
            width: 30px;
            height: 30px;
            border: 1px solid #ccc;
            background: #f5f5f5;
            cursor: pointer;
            display: flex;
            align-items: center;
            justify-content: center;
            font-weight: bold;
        }
        .format-btn:hover {
            background: #e5e5e5;
        }

        .manage-posts {
            position: fixed;
            top: 0;
            right: 0;
            bottom: 0;
            width: 300px;
            background: white;
            border-left: 1px solid #ddd;
            padding: 20px;
            overflow-y: auto;
            transform: translateX(100%);
            transition: transform 0.3s;
            box-shadow: -2px 0 5px rgba(0,0,0,0.1);
        }
        
        .manage-posts.active {
            transform: translateX(0);
        }
        
        .post-list {
            list-style: none;
            padding: 0;
        }
        
        .post-item {
            padding: 10px;
            border-bottom: 1px solid #eee;
            position: relative;
        }
        
        .delete-btn {
            position: absolute;
            right: 10px;
            top: 50%;
            transform: translateY(-50%);
            background: #ff4444;
            color: white;
            border: none;
            padding: 5px 10px;
            border-radius: 3px;
            cursor: pointer;
        }
        
        .delete-btn:hover {
            background: #ff0000;
        }
        
        .manage-btn {
            position: fixed;
            top: 20px;
            right: 20px;
            padding: 10px 20px;
            background: #4CAF50;
            color: white;
            border: none;
            border-radius: 3px;
            cursor: pointer;
        }
        
        .manage-btn:hover {
            background: #45a049;
        }
        
        .close-manage {
            position: absolute;
            top: 10px;
            right: 10px;
            background: none;
            border: none;
            font-size: 20px;
            cursor: pointer;
        }

        .dialog {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: rgba(0,0,0,0.5);
            z-index: 1000;
        }

        .dialog-content {
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            background: white;
            padding: 20px;
            border-radius: 5px;
            min-width: 300px;
        }

        .image-size-controls {
            margin: 15px 0;
        }

        .dialog-buttons {
            display: flex;
            gap: 10px;
            justify-content: flex-end;
            margin-top: 15px;
        }

        #customSizeInputs {
            margin-top: 10px;
            display: flex;
            gap: 10px;
        }

        #customSizeInputs input {
            width: 100px;
        }

        .edit-btn {
            position: absolute;
            right: 80px;
            top: 50%;
            transform: translateY(-50%);
            background: #4CAF50;
            color: white;
            border: none;
            padding: 5px 10px;
            border-radius: 3px;
            cursor: pointer;
        }
        
        .edit-btn:hover {
            background: #45a049;
        }

        #submitButton {
            background: #4CAF50;
            color: white;
            border: none;
            padding: 10px 20px;
            border-radius: 3px;
            cursor: pointer;
        }

        #submitButton.editing {
            background: #ff9800;
        }
    </style>
</head>
<body>
    <h1>Добавить новую статью</h1>
    <form id="blogForm">
        <input type="text" id="title" placeholder="Заголовок статьи" required>
        <div class="formatting-buttons">
            <button type="button" class="format-btn" onclick="formatText('b')" title="Жирный">B</button>
            <button type="button" class="format-btn" onclick="formatText('i')" title="Курсив"><i>I</i></button>
            <button type="button" class="format-btn" onclick="formatText('u')" title="Подчеркнутый">U</button>
            <button type="button" class="format-btn" onclick="formatText('h2')" title="Подзаголовок">H</button>
            <button type="button" class="format-btn" onclick="insertList()" title="Список">•</button>
            <button type="button" class="format-btn" onclick="addLink()" title="Ссылка">🔗</button>
            <button type="button" class="format-btn" onclick="showImageUpload()" title="Добавить изображение">📷</button>
        </div>
        <textarea id="content" placeholder="Содержание статьи" required></textarea>
        <button type="submit" id="submitButton">Опубликовать</button>
    </form>

    <button type="button" class="manage-btn" onclick="toggleManagePosts()">Управление статьями</button>

    <div class="manage-posts" id="managePosts">
        <button class="close-manage" onclick="toggleManagePosts()">×</button>
        <h2>Все статьи</h2>
        <div id="postsList"></div>
    </div>
    
    <div id="imageUploadDialog" class="dialog">
        <div class="dialog-content">
            <h3>Загрузить изображение</h3>
            <input type="file" id="imageFile" accept="image/*">
            <div class="image-size-controls">
                <label>
                    Размер:
                    <select id="imageSize">
                        <option value="small">Маленький</option>
                        <option value="medium" selected>Средний</option>
                        <option value="large">Большой</option>
                        <option value="custom">Свой размер</option>
                    </select>
                </label>
                <div id="customSizeInputs" style="display: none;">
                    <input type="number" id="customWidth" placeholder="Ширина (px)">
                    <input type="number" id="customHeight" placeholder="Высота (px)">
                </div>
            </div>
            <div class="dialog-buttons">
                <button onclick="uploadImage()">Загрузить</button>
                <button onclick="closeImageDialog()">Отмена</button>
            </div>
        </div>
    </div>

    <script>
        let currentEditId = null;

        function formatText(tag) {
            const textarea = document.getElementById('content');
            const start = textarea.selectionStart;
            const end = textarea.selectionEnd;
            const selectedText = textarea.value.substring(start, end);
            const beforeText = textarea.value.substring(0, start);
            const afterText = textarea.value.substring(end);

            let formattedText;
            if (tag === 'h2') {
                formattedText = `<${tag}>${selectedText}</${tag}>\n`;
            } else {
                formattedText = `<${tag}>${selectedText}</${tag}>`;
            }

            textarea.value = beforeText + formattedText + afterText;
            textarea.focus();
            textarea.setSelectionRange(start + tag.length + 2, start + tag.length + 2 + selectedText.length);
        }

        function insertList() {
            const textarea = document.getElementById('content');
            const listTemplate = "\n<ul>\n  <li>Пункт 1</li>\n  <li>Пункт 2</li>\n  <li>Пункт 3</li>\n</ul>\n";
            const cursorPos = textarea.selectionStart;
            textarea.value = textarea.value.substring(0, cursorPos) + listTemplate + textarea.value.substring(cursorPos);
            textarea.focus();
        }

        function addLink() {
            const textarea = document.getElementById('content');
            const url = prompt('Введите URL:', 'https://');
            if (url) {
                const selectedText = textarea.value.substring(textarea.selectionStart, textarea.selectionEnd);
                const linkText = selectedText || 'ссылка';
                const link = `<a href="${url}">${linkText}</a>`;
                
                const start = textarea.selectionStart;
                textarea.value = textarea.value.substring(0, start) + 
                               link + 
                               textarea.value.substring(textarea.selectionEnd);
            }
        }

        function showImageUpload() {
            document.getElementById('imageUploadDialog').style.display = 'block';
        }

        function closeImageDialog() {
            document.getElementById('imageUploadDialog').style.display = 'none';
            document.getElementById('imageFile').value = '';
        }

        function uploadImage() {
            const file = document.getElementById('imageFile').files[0];
            if (!file) {
                alert('Пожалуйста, выберите файл');
                return;
            }

            const formData = new FormData();
            formData.append('image', file);

            const sizeSelect = document.getElementById('imageSize');
            const sizeValue = sizeSelect.value;
            
            let width, height;
            if (sizeValue === 'custom') {
                width = document.getElementById('customWidth').value;
                height = document.getElementById('customHeight').value;
            } else {
                const sizes = {
                    small: { width: 300 },
                    medium: { width: 500 },
                    large: { width: 800 }
                };
                width = sizes[sizeValue].width;
            }

            formData.append('width', width);
            formData.append('height', height || '');

            fetch('upload_image.php', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    const imgTag = `<img src="${data.url}" style="width: ${width}px; ${height ? 'height: ' + height + 'px;' : ''}" class="blog-image">`;
                    const textarea = document.getElementById('content');
                    const cursorPos = textarea.selectionStart;
                    textarea.value = textarea.value.substring(0, cursorPos) + 
                                   imgTag + 
                                   textarea.value.substring(cursorPos);
                    closeImageDialog();
                } else {
                    alert('Ошибка при загрузке изображения: ' + data.error);
                }
            })
            .catch(error => {
                alert('Ошибка при загрузке изображения');
            });
        }

        function toggleManagePosts() {
            const managePanel = document.getElementById('managePosts');
            managePanel.classList.toggle('active');
            
            if (managePanel.classList.contains('active')) {
                loadPosts();
            }
        }

        function loadPosts() {
            fetch('get_posts.php')
                .then(response => response.json())
                .then(posts => {
                    const postsList = document.getElementById('postsList');
                    postsList.innerHTML = '<ul class="post-list">' +
                        posts.map(post => `
                            <li class="post-item">
                                <div>${post.title}</div>
                                <small>${post.date}</small>
                                <button class="edit-btn" onclick="editPost('${post.id}')">Редактировать</button>
                                <button class="delete-btn" onclick="deletePost('${post.id}')">Удалить</button>
                            </li>
                        `).join('') +
                        '</ul>';
                });
        }

        function editPost(postId) {
            fetch('get_post_content.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ id: postId })
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    document.getElementById('title').value = data.title;
                    document.getElementById('content').value = data.content;
                    currentEditId = postId;
                    
                    const submitButton = document.getElementById('submitButton');
                    submitButton.textContent = 'Сохранить изменения';
                    submitButton.classList.add('editing');
                    
                    toggleManagePosts();
                    document.getElementById('blogForm').scrollIntoView();
                }
            });
        }

        function deletePost(postId) {
            if (confirm('Вы уверены, что хотите удалить эту статью?')) {
                fetch('delete_post.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({ id: postId })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        loadPosts();
                    } else {
                        alert('Ошибка при удалении статьи');
                    }
                });
            }
        }

        document.getElementById('blogForm').addEventListener('submit', function(e) {
            e.preventDefault();
            
            const title = document.getElementById('title').value;
            const content = document.getElementById('content').value;
            
            const endpoint = currentEditId ? 'update_post.php' : 'save_post.php';
            const data = {
                title: title,
                content: content
            };
            
            if (currentEditId) {
                data.id = currentEditId;
            }
            
            fetch(endpoint, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify(data)
            })
            .then(response => response.text())
            .then(data => {
                alert(currentEditId ? 'Статья успешно обновлена!' : 'Статья успешно добавлена!');
                document.getElementById('blogForm').reset();
                
                currentEditId = null;
                const submitButton = document.getElementById('submitButton');
                submitButton.textContent = 'Опубликовать';
                submitButton.classList.remove('editing');
            })
            .catch(error => {
                alert('Ошибка при сохранении статьи');
            });
        });

        document.getElementById('imageSize').addEventListener('change', function(e) {
            const customInputs = document.getElementById('customSizeInputs');
            customInputs.style.display = e.target.value === 'custom' ? 'flex' : 'none';
        });
    </script>
</body>
</html>